** calculator**

This package helps in performing arithmetic operation.

**Installing package**

pip Install calculatorpackage_harimythily
 
**function in example.py**
addition(a,b)
add two numbers

subtraction(a,b)
subtract two numbers

multiplication(a,b)
multiply two numbers

division(a,b)
divide two numbers

getinput()
get input from user